Documentation
¶
Overview ¶
Copyright © 2024 thisni1s thisni1s@jn2p.de
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
Copyright © 2024 thisni1s thisni1s@jn2p.de
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
Copyright © 2024 NAME HERE <EMAIL ADDRESS>
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckOccupationArg ¶
func CheckOccupationArg(input string) namiTypes.TAETIGKEIT
func CheckSubdivisionArg ¶
func CheckSubdivisionArg(input string) namiTypes.UNTERGLIEDERUNG
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func GetGroupId ¶
func GetGroupId() string
func PrintSearchResult ¶
func PrintSearchResult(members []namiTypes.SearchMember)
Types ¶
type SepaConfig ¶
type SepaMailConfig ¶
type SepaMailConfig struct {
Username string `yaml:"Username"`
Fromname string `yaml:"Fromname"`
Password string `yaml:"Password"`
Server string `yaml:"Server"`
Subject string `yaml:"Subject"`
Template string `yaml:"Template"`
FeeFull float64 `yaml:"FeeFull"`
FeeFam float64 `yaml:"FeeFam"`
FeeSocial float64 `yaml:"FeeSocial"`
FeeLeader float64 `yaml:"FeeLeader"`
FeePassive float64 `yaml:"FeePassive"`
}